# Create rpm package with usual location and root ownership of files.
# However, I have made consistent changes so that this package can be
# generated (as opposed to installed) in a non-critical area by **any user**
# (root or non-root).  In my opinion this is the only safe way to generate
# packages.  The only un-safe part is actually installing (as opposed to
# generating) the package.  However, before the install you should be checking
# the file list and the file attributes in any case to make sure you are not
# overwriting something critical.
# N.B Use rm -rf /tmp/software/redhat_install_area/plplot before building
# this package.  This could be done automatically, but it is safer
# to do it by hand since BuildRoot can be overridden from outside.
BuildRoot: /tmp/software/redhat_install_area/plplot
# N.B. note use of $RPM_BUILD_ROOT in the %prep and %install areas.
Summary: PLPlot 2D/3D plotting library
Packager: Conrad Steenberg <conrad@srl.caltech.edu>
Name: plplot
Version: 990122
Release: 1
Source: http://emma.la.asu.edu/plplot/source/plplot-990122.tar.gz
URL: http://emma.la.asu.edu/plplot/
# Don't use the Source# symbolic links, but mention them here to
# indicate these source files are required.
Source1: ftp://dino.ph.utexas.edu/plplot/docs/plplot.dvi.gz
Source2: ftp://dino.ph.utexas.edu/plplot/docs/plplot.ps.gz
Source3: ftp://dino.ph.utexas.edu/plplot/docs/plplot.info.gz
Patch0: plplot-990122.patch.gz
# Don't use the Patch1 symbolic link, but mention it here to indicate
# this patch file is required.
Patch1: plplot.info.patch.gz
Copyright: LGPL with some exceptions, see file "Copyright"
Group: Applications/Math
%description
This is the distribution for PLplot, a scientific plotting package. PLplot
is relatively small, portable, freely distributable, and is rich enough to
satisfy most users.  It has a wide range of plot types including line
(linear, log), contour, 3D, fill, and almost 1000 characters (including
Greek and mathematical) in its extended font set.  The package is designed
to make it easy to quickly get graphical output; only a handful of function
calls is typically required.  For more advanced use, virtually all aspects
of plotting are configurable.

Notes on the plplot version underlying this package: 
This package is built on the 1999 January 22 (990122) beta release of
plplot-4.99 which supersedes much earlier beta releases of 4.99 such as the
plplot-4.99j (see URL).  NOTE CAREFULLY that the latest beta might break
your previous use of plplot.  As always closely follow the examples (which
have been checked to work for the compilation method used in the Makefile).
The changes made to 990122 for the rpm package are specific modifications of
the configuration to allow building on a RedHat 5.2 glibc system.  In
addition, patches were made to plbox.c, plot3d.c, and pldtik.c to squelch
bugs in the gridding, and axis ticks and labelling.  These bugs occurred for
decreasing Z, certain 3D azimuth quadrants, and decreasing X and/or Y for 2D
plots.  The sign of user-specified tick spacing is now ignored. To create
the present rpm, configure script options were employed for double
precision, and to exclude the fortran and c++ interfaces (which implement
the double precision option with compiler options not recognized by the g77
and g++ compilers). Symlinks were created that point from the correct Redhat
directories to the plplot includes, binaries, and dynamic libraries that are
installed under /usr/lib/plplot. The dynamic library version symlinks now
correspond to the usual convention. Finally, dvi, postscript, and info
versions of the plplot documentation that were separately available were
imported into the rpm package.

%prep
%setup
%patch -p1
# note I used the --compile_install_prefix and propagated it so that
# the C code had access to the final location (not the intermediate safe
# location) that the software would be installed by the rpm -i command.
./configure --compile_install_prefix=/usr/lib/plplot \
--prefix=$RPM_BUILD_ROOT/usr/lib/plplot --with-double --disable-cxx \
--without-f2c --disable-f77 --disable-itcl --disable-dp
cd doc
cp $RPM_SOURCE_DIR/plplot.dvi.gz ./
cp $RPM_SOURCE_DIR/plplot.ps.gz ./
cp $RPM_SOURCE_DIR/plplot.info.gz ./
gunzip plplot.info.gz
gunzip -c $RPM_SOURCE_DIR/plplot.info.patch.gz | patch -p0 -s
gzip plplot.info
%build
make 
%install
make install 
#install extra documentation
cp doc/plplot.dvi.gz $RPM_BUILD_ROOT/usr/lib/plplot/doc
cp doc/plplot.ps.gz $RPM_BUILD_ROOT/usr/lib/plplot/doc
install -m 755 -d $RPM_BUILD_ROOT/usr/info
cp doc/plplot.info.gz $RPM_BUILD_ROOT/usr/info
# make install already copies system header files + one internal
# header file (plplotP.h).  Now copy remaining "internal" headers.
cd tmp
cp \
drivers.h \
metadefs.h \
plConfig.h \
plDevs.h \
plcdemos.h \
plcore.h \
pldebug.h \
plserver.h \
pltkd.h \
tclgen.h \
tclgen_s.h \
tcpip.h \
$RPM_BUILD_ROOT/usr/lib/plplot/include
# generate include, bin, and lib symlinks
# No name clashes found, but because of potential concern we
# exclude from the include list all the internal headers.
install -m 755 -d $RPM_BUILD_ROOT/usr/include
ln -s ../lib/plplot/include/plplot.h $RPM_BUILD_ROOT/usr/include/plplot.h
ln -s ../lib/plplot/include/plxwd.h $RPM_BUILD_ROOT/usr/include/plxwd.h
ln -s ../lib/plplot/include/plevent.h $RPM_BUILD_ROOT/usr/include/plevent.h
ln -s ../lib/plplot/include/plstrm.h $RPM_BUILD_ROOT/usr/include/plstrm.h
ln -s ../lib/plplot/include/pdf.h $RPM_BUILD_ROOT/usr/include/pdf.h
ln -s ../lib/plplot/include/tclMatrix.h $RPM_BUILD_ROOT/usr/include/tclMatrix.h
ln -s ../lib/plplot/include/pltcl.h $RPM_BUILD_ROOT/usr/include/pltcl.h
ln -s ../lib/plplot/include/pltk.h $RPM_BUILD_ROOT/usr/include/pltk.h
install -m 755 -d $RPM_BUILD_ROOT/usr/bin
ln -s ../lib/plplot/bin/plm2gif $RPM_BUILD_ROOT/usr/bin/plm2gif
ln -s ../lib/plplot/bin/plpr $RPM_BUILD_ROOT/usr/bin/plpr
ln -s ../lib/plplot/bin/plrender $RPM_BUILD_ROOT/usr/bin/plrender
ln -s ../lib/plplot/bin/plserver $RPM_BUILD_ROOT/usr/bin/plserver
ln -s ../lib/plplot/bin/pltcl $RPM_BUILD_ROOT/usr/bin/pltcl
ln -s ../lib/plplot/bin/pltek $RPM_BUILD_ROOT/usr/bin/pltek
install -m 755 -d $RPM_BUILD_ROOT/usr/lib
ln -s libMatrix.so.4 $RPM_BUILD_ROOT/usr/lib/libMatrix.so
ln -s libMatrix.so.4.99.990122 $RPM_BUILD_ROOT/usr/lib/libMatrix.so.4
ln -s plplot/lib/libMatrix.so.4.99.990122 $RPM_BUILD_ROOT/usr/lib/libMatrix.so.4.99.990122
ln -s libplplotdtk.so.4 $RPM_BUILD_ROOT/usr/lib/libplplotdtk.so
ln -s libplplotdtk.so.4.99.990122 $RPM_BUILD_ROOT/usr/lib/libplplotdtk.so.4
ln -s plplot/lib/libplplotdtk.so.4.99.990122 $RPM_BUILD_ROOT/usr/lib/libplplotdtk.so.4.99.990122
%post
/sbin/ldconfig
/sbin/install-info /usr/info/plplot.info.gz /usr/info/dir
%preun
if [ $1 = 0 ]; then
   /sbin/install-info --delete /usr/info/plplot.info.gz /usr/info/dir
fi
%postun
/sbin/ldconfig
%files
# The other potential documentation files in /usr/lib/plplot/doc are so ancient 
# they are misleading so don't put extra copy of these files in /usr/doc.
%attr(-, root, root) %doc README Copyright
%attr(-, root, root) /usr/lib/plplot
# info file
%attr(-, root, root) /usr/info/plplot.info.gz
# include (excluding internal headers), bin, and lib symlinks
%attr(-, root, root) /usr/include/plplot.h
%attr(-, root, root) /usr/include/plxwd.h
%attr(-, root, root) /usr/include/plevent.h
%attr(-, root, root) /usr/include/plstrm.h
%attr(-, root, root) /usr/include/pdf.h
%attr(-, root, root) /usr/include/tclMatrix.h
%attr(-, root, root) /usr/include/pltcl.h
%attr(-, root, root) /usr/include/pltk.h
%attr(-, root, root) /usr/bin/plm2gif
%attr(-, root, root) /usr/bin/plpr
%attr(-, root, root) /usr/bin/plrender
%attr(-, root, root) /usr/bin/plserver
%attr(-, root, root) /usr/bin/pltcl
%attr(-, root, root) /usr/bin/pltek
%attr(-, root, root) /usr/lib/libMatrix.so
%attr(-, root, root) /usr/lib/libMatrix.so.4
%attr(-, root, root) /usr/lib/libMatrix.so.4.99.990122
%attr(-, root, root) /usr/lib/libplplotdtk.so
%attr(-, root, root) /usr/lib/libplplotdtk.so.4
%attr(-, root, root) /usr/lib/libplplotdtk.so.4.99.990122
